import { jsx } from 'react/jsx-runtime';
import Input from '@rescui/input';
import { useField, useFormikContext } from 'formik';

const FormikInput = ({
  name,
  onBlur,
  onChange,
  disabled,
  ...restProps
}) => {
  const [formikProps, meta] = useField(name);
  const {
    status,
    isSubmitting,
    submitCount
  } = useFormikContext();
  return jsx(Input, Object.assign({}, restProps, formikProps, {
    onBlur: e => {
      if (onBlur) {
        onBlur(e);
      }

      formikProps.onBlur(e);
    },
    onChange: e => {
      if (onChange) {
        onChange(e);
      }

      formikProps.onChange(e);
    },
    disabled: isSubmitting || status && (status.disabled || status.submitted) || disabled,
    error: (meta.touched || submitCount > 0) && meta.error
  }), void 0);
};

export { FormikInput };
