import { jsx } from 'react/jsx-runtime';
import { useField, useFormikContext } from 'formik';
import { PrivacyNotice } from './privacy-notice.js';
import { Checkbox } from '@rescui/checkbox';

const FormikPrivacyCheckbox = ({
  consentId,
  className,
  privacy
}) => {
  const name = 'privacyConsent';
  const [{
    value,
    onBlur: onBlurFromFormik
  }, meta] = useField({
    name,
    validate: val => {
      if (!val) {
        return 'This field is required';
      }
    }
  });
  const {
    submitCount,
    setFieldValue,
    isSubmitting,
    status
  } = useFormikContext();
  return jsx("div", Object.assign({
    className: className
  }, {
    children: jsx(Checkbox, Object.assign({
      name: name,
      onBlur: e => {
        onBlurFromFormik(e);
      },
      onChange: e => {
        setFieldValue(name, e.target.checked);
      },
      checked: Boolean(value) || false,
      disabled: isSubmitting || status && (status.disabled || status.submitted),
      error: (meta.touched || submitCount > 0) && meta.error
    }, {
      children: jsx(PrivacyNotice, {
        consentId: consentId,
        privacy: privacy
      }, void 0)
    }), void 0)
  }), void 0);
};

export { FormikPrivacyCheckbox };
