import { jsxs, jsx } from 'react/jsx-runtime';
import { useTheme } from '@rescui/ui-contexts';
import { SocialList } from './social-list/social-list.js';
import { NavList } from './nav/nav-list.js';
import { Logo } from './logo/logo.js';
import classNames from 'classnames';
import styles from './footer.module.pcss.js';
import { useTextStyles } from '@rescui/typography';

const Footer = ({
  forwardedRef,
  className
}) => {
  const textCn = useTextStyles();
  const theme = useTheme();
  const linkClass = textCn('rs-link', {
    hardness: 'pale',
    mode: 'clear'
  });
  return jsxs("footer", Object.assign({
    className: classNames(styles.footer, className, {
      [styles.footerDarkTheme]: theme === 'dark'
    }),
    ref: forwardedRef
  }, {
    children: [jsxs("div", Object.assign({
      className: styles.socialListArea
    }, {
      children: [jsx("div", Object.assign({
        className: classNames(textCn('rs-h4'), styles.socialListTitle)
      }, {
        children: "Stay in touch:"
      }), void 0), jsx(SocialList, {}, void 0)]
    }), void 0), jsx(NavList, {
      className: styles.navListArea
    }, void 0), jsxs("div", Object.assign({
      className: classNames(textCn('rs-text-3', {
        hardness: 'pale'
      }), styles.textArea)
    }, {
      children: [jsxs("div", Object.assign({
        className: styles.copyright
      }, {
        children: ["Kotlin\u2122 is\u00A0protected under the", ' ', jsx("a", Object.assign({
          className: classNames(linkClass, styles.underlinedLink),
          href: "https://kotlinlang.org/foundation/kotlin-foundation.html"
        }, {
          children: "Kotlin\u00A0Foundation"
        }), void 0), ' ', "and licensed under the", ' ', jsx("a", Object.assign({
          className: classNames(linkClass, styles.underlinedLink),
          target: "_blank",
          href: "https://github.com/JetBrains/kotlin-web-site/blob/master/LICENSE"
        }, {
          children: "Apache 2\u00A0license"
        }), void 0), "."]
      }), void 0), ' ', jsxs("div", Object.assign({
        className: styles.motto
      }, {
        children: ["Supported and developed by\u00A0", jsx("a", Object.assign({
          className: classNames(linkClass, styles.underlinedLink),
          href: "https://www.jetbrains.com/",
          target: "_blank"
        }, {
          children: "JetBrains"
        }), void 0)]
      }), void 0)]
    }), void 0), jsx(Logo, {
      className: styles.logoArea
    }, void 0)]
  }), void 0);
};

export { Footer };
