import { jsx, jsxs } from 'react/jsx-runtime';
import { forwardRef, useState, useMemo, useRef, useImperativeHandle, useLayoutEffect } from 'react';
import { ThemeProvider } from '@rescui/ui-contexts';
import useResizeObserver from '@react-hook/resize-observer';
import { LogoLarge } from './logo-large/logo-large.js';
import styles from './header.module.pcss.js';
import { getNavScheme } from './nav-scheme.js';
import { HorizontalMenu } from './horizontal-menu/horizontal-menu.js';
import { SearchButton } from './search-button/search-button.js';
import { MenuPopup } from './menu-popup/menu-popup.js';
import { LogoSmall } from './logo-small/logo-small.js';
import classNames from 'classnames';
const MENU_POPUP_BREAKPOINT = 640;
const Header = forwardRef(({
  productWebUrl,
  hasSearch = false,
  onSearchClick,
  currentUrl,
  currentTitle,
  className,
  hasBorder = true,
  dropdownTheme = 'dark',
  linkHandler,
  isPlayground,
  isUrlActive
}, forwardedRef) => {
  const [menuPopupExpanded, setMenuPopupExpanded] = useState(false);
  const [isMenuPopupVisible, setIsMenuPopupVisible] = useState(false);
  const items = useMemo(() => getNavScheme(isUrlActive, currentUrl, isPlayground), [isUrlActive, currentUrl, isPlayground]);
  const headerRef = useRef(null);
  useImperativeHandle(forwardedRef, () => headerRef.current);
  useLayoutEffect(() => {
    setIsMenuPopupVisible((headerRef.current?.getBoundingClientRect?.().width ?? 0) <= MENU_POPUP_BREAKPOINT);
  }, [headerRef]);
  useResizeObserver(headerRef, entry => setIsMenuPopupVisible(entry.contentRect.width <= MENU_POPUP_BREAKPOINT));
  return jsx(ThemeProvider, Object.assign({
    theme: 'dark'
  }, {
    children: jsxs("header", Object.assign({
      ref: headerRef,
      className: classNames(styles.headerMenu, className, {
        [styles.withMenuPopup]: menuPopupExpanded,
        [styles.border]: hasBorder
      })
    }, {
      children: [isMenuPopupVisible && currentTitle && currentUrl && !menuPopupExpanded ? jsx(LogoSmall, {
        homeTitle: currentTitle,
        homeUrl: currentUrl
      }, void 0) : jsx(LogoLarge, {
        productWebUrl: productWebUrl
      }, void 0), !isMenuPopupVisible && jsx(HorizontalMenu, {
        items: items,
        theme: dropdownTheme,
        linkHandler: linkHandler
      }, void 0), jsx(SearchButton, {
        onClick: onSearchClick,
        isActive: hasSearch && !!onSearchClick
      }, void 0), isMenuPopupVisible && jsx(MenuPopup, {
        items: items,
        setExpand: setMenuPopupExpanded,
        isExpanded: menuPopupExpanded,
        headerRef: headerRef,
        linkHandler: linkHandler
      }, void 0)]
    }), void 0)
  }), void 0);
});
export { Header };
