import { useState, useEffect, createElement } from 'react';
import { jsx, jsxs } from 'react/jsx-runtime';
import classNames from 'classnames';
import styles from './horizontal-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';

const DropdownMenu = ({
  items,
  isExpanded,
  alignRight,
  linkHandler
}) => {
  const textCn = useTextStyles();
  return jsx("ul", Object.assign({
    className: classNames(styles.dropdownMenu, textCn('rs-text-2'), {
      [styles.dropdownMenuExpanded]: isExpanded,
      [styles.dropdownMenuAlignRight]: alignRight
    })
  }, {
    children: items.map((item, key) => {
      const Tag = !item.isActive && item.url ? 'a' : 'span';
      return jsx("li", {
        children: jsx(Tag, Object.assign({
          className: classNames(styles.dropdownMenuItem, {
            [styles.active]: item.isActive
          })
        }, item.url ? {
          href: item.url,
          onClick: linkHandler ? event => item.url && linkHandler(event, item.url) : undefined
        } : {}, {
          children: item.title
        }), void 0)
      }, key);
    })
  }), void 0);
};

const HorizontalMenuItem = ({
  item,
  onMouseEnter,
  onMouseLeave,
  isExpanded,
  isLast,
  linkHandler
}) => {
  const Tag = item.isActive || !item.url ? 'span' : 'a';
  const textCn = useTextStyles();

  const handleEnter = () => onMouseEnter(item);

  return jsxs("li", Object.assign({
    className: styles.menuItemWrap,
    onMouseEnter: handleEnter,
    onMouseLeave: onMouseLeave
  }, {
    children: [createElement(Tag, Object.assign({}, item.url ? {
      href: item.url,
      onClick: linkHandler ? event => item.url && linkHandler(event, item.url) : undefined
    } : {}, {
      key: item.title,
      className: classNames(styles.menuItem, textCn('rs-text-2'), {
        [styles.itemActive]: item.isActive,
        [styles.expanded]: isExpanded && !!item.items?.length
      })
    }), item.title), !!item.items?.length && jsx(DropdownMenu, {
      items: item.items,
      isExpanded: isExpanded,
      alignRight: isLast,
      linkHandler: linkHandler
    }, void 0)]
  }), void 0);
};

const HorizontalMenu = ({
  items,
  theme,
  linkHandler
}) => {
  const [activeIndex, setActiveIndex] = useState(-1);
  const [debouncedActiveIndex, setDebouncedActiveIndex] = useState(activeIndex);
  useEffect(() => {
    const handler = setTimeout(() => setDebouncedActiveIndex(activeIndex), activeIndex !== -1 ? 200 : 400);
    return () => clearTimeout(handler);
  }, [activeIndex]);

  const handleEnter = item => setActiveIndex(items.findIndex(val => val === item));

  const handleLeave = () => setActiveIndex(-1);

  return jsx("nav", Object.assign({
    className: classNames(styles.nav, {
      [styles.darkTheme]: theme === 'dark'
    })
  }, {
    children: jsx("ul", Object.assign({
      className: styles.menuList
    }, {
      children: items.map((item, index) => jsx(HorizontalMenuItem, {
        item: item,
        onMouseEnter: handleEnter,
        onMouseLeave: handleLeave,
        isExpanded: index === debouncedActiveIndex,
        isLast: index === items.length - 1,
        linkHandler: linkHandler
      }, index))
    }), void 0)
  }), void 0);
};

export { HorizontalMenu };
