import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import { useRef, useState, useEffect, useLayoutEffect, useCallback, Fragment as Fragment$1 } from 'react';
import styles from './menu-popup.module.pcss.js';
import classNames from 'classnames';
import { MenuButton } from './menu-button/menu-button.js';
import { useTextStyles } from '@rescui/typography';
import { clearAllBodyScrollLocks, enableBodyScroll, disableBodyScroll } from 'body-scroll-lock';

const MenuListItem = ({
  item,
  level,
  linkHandler
}) => {
  const Tag = item.url ? 'a' : 'span';
  const style = {
    '--level': level
  };
  const handleClick = useCallback(event => linkHandler && item.url && linkHandler(event, item.url), []);
  return jsx(Tag, Object.assign({}, item.url ? {
    href: item.url,
    onClick: handleClick
  } : {}, {
    className: classNames(styles.menuItem, {
      [styles.menuItemRoot]: level === 0,
      [styles.active]: item.isActive,
      [styles.activeWithChild]: item.items && item.items.length
    }),
    style: style
  }, {
    children: item.title
  }), void 0);
};

const MenuList = ({
  items,
  level,
  linkHandler
}) => {
  return jsx(Fragment, {
    children: items.map((item, i) => jsxs(Fragment$1, {
      children: [jsx(MenuListItem, {
        item: item,
        level: level,
        linkHandler: linkHandler
      }, void 0), item.items && item.items.length > 0 && jsx(MenuList, {
        items: item.items,
        level: level + 1,
        linkHandler: linkHandler
      }, void 0)]
    }, i))
  }, void 0);
};

const MenuPopup = ({
  items,
  isExpanded,
  setExpand,
  headerRef,
  linkHandler
}) => {
  const navRef = useRef(null);
  const textCn = useTextStyles();
  const [navStyle, setNavStyle] = useState({});
  useEffect(() => {
    return () => {
      setExpand(false);
      clearAllBodyScrollLocks();
    };
  }, []);
  useLayoutEffect(() => {
    if (headerRef.current) {
      setNavStyle({
        top: headerRef.current.getBoundingClientRect().bottom
      });
    }
  }, [isExpanded, headerRef]);
  const handleClick = useCallback(() => {
    if (navRef.current) {
      isExpanded ? enableBodyScroll(navRef.current) : disableBodyScroll(navRef.current);
    }

    setExpand(!isExpanded);
  }, [isExpanded, navRef]);
  return jsxs(Fragment, {
    children: [jsx(MenuButton, {
      onClick: handleClick,
      isExpanded: isExpanded
    }, void 0), jsx("nav", Object.assign({
      style: navStyle,
      ref: navRef,
      className: classNames(styles.menuPopup, textCn('rs-text-2'), {
        [styles.menuPopupExpanded]: isExpanded
      })
    }, {
      children: jsx(MenuList, {
        items: items,
        level: 0,
        linkHandler: linkHandler
      }, void 0)
    }), void 0)]
  }, void 0);
};

export { MenuPopup };
