import { jsx, jsxs } from 'react/jsx-runtime';
import ReactModal from 'react-modal';
import { LayeringConsumer, LayeringProvider } from '@rescui/ui-contexts';
import { CloseIcon, LoadingIcon } from '@rescui/icons';
import { RemoveScrollBar } from 'react-remove-scroll-bar';
import Button from '@rescui/button';
import styles from './popup.module.pcss.js';

const Popup = ({
  isOpen,
  children,
  onRequestClose,
  shouldCloseOnEsc = true,
  shouldCloseOnOverlayClick = true,
  busy = false,
  showOuterCloseButton = false,
  ariaHideApp = false,
  ...restProps
}) => {
  return jsx(LayeringConsumer, {
    children: ({
      popupZIndex
    }) => jsx(LayeringProvider, Object.assign({
      baseLayer: "popup"
    }, {
      children: jsxs(ReactModal, Object.assign({
        isOpen: isOpen,
        className: styles.popup,
        overlayClassName: styles.overlay,
        onRequestClose: onRequestClose,
        shouldCloseOnOverlayClick: shouldCloseOnOverlayClick,
        shouldCloseOnEsc: shouldCloseOnEsc
      }, restProps, {
        ariaHideApp: ariaHideApp,
        style: {
          overlay: {
            zIndex: popupZIndex
          }
        }
      }, {
        children: [!busy && showOuterCloseButton && jsx(Button, {
          mode: 'rock',
          theme: 'light',
          icon: jsx(CloseIcon, {}, void 0),
          className: styles.close,
          onClick: onRequestClose,
          "data-test": "close-button"
        }, void 0), busy ? jsx(LoadingIcon, {
          size: "l",
          theme: "dark",
          mode: "rock",
          "data-test": "loading-icon"
        }, void 0) : children, jsx(RemoveScrollBar, {
          gapMode: "margin"
        }, void 0)]
      }), void 0)
    }), void 0)
  }, void 0);
};

export { Popup };
