import { jsx, jsxs } from 'react/jsx-runtime';
import { useState, useCallback } from 'react';
import SwipeableViews from 'react-swipeable-views';
import cn from 'classnames';
import SvgQuote from './quote.svg.js';
import SvgSliderArrow from './slider-arrow.svg.js';
import styles from './quotes-slider.module.pcss.js';

const QuotesSlider = ({
  quotes,
  large
}) => {
  const [index, setIndex] = useState(0);
  const totalSlides = quotes.length;
  const handleNextSlide = useCallback(() => {
    if (index + 1 < totalSlides) {
      setIndex(index + 1);
    }
  }, [index]);
  const handlePrevSlide = useCallback(() => {
    if (index > 0) {
      setIndex(index - 1);
    }
  }, [index]);
  const handleChangeIndex = useCallback(i => {
    setIndex(i);
  }, [index]);
  const slideTitle = quotes[index].title;
  const prevButtonClass = cn([styles.control, styles.controlPrev], {
    [styles.controlActive]: index > 0
  });
  const nextButtonClass = cn(styles.control, {
    [styles.controlActive]: index + 1 < totalSlides
  });
  const quoteTextClass = large ? 'ktl-subtitle' : 'ktl-text-1';
  return jsx("div", Object.assign({
    className: styles.quotesSlider
  }, {
    children: jsxs("div", Object.assign({
      className: styles.content
    }, {
      children: [jsx("div", Object.assign({
        className: styles.iconContainer
      }, {
        children: jsx(SvgQuote, {}, void 0)
      }), void 0), jsxs("div", {
        children: [quotes.length > 1 ? jsx(SwipeableViews, Object.assign({
          index: index,
          onChangeIndex: handleChangeIndex
        }, {
          children: quotes.map((quote, i) => jsx("p", Object.assign({
            className: quoteTextClass
          }, {
            children: quote.text
          }), i))
        }), void 0) : jsx("p", Object.assign({
          className: quoteTextClass
        }, {
          children: quotes[0].text
        }), void 0), jsxs("div", Object.assign({
          className: styles.nav
        }, {
          children: [jsx("div", Object.assign({
            className: styles.title
          }, {
            children: jsx("p", Object.assign({
              className: "ktl-text-2"
            }, {
              children: slideTitle
            }), void 0)
          }), void 0), quotes.length > 1 && jsxs("div", Object.assign({
            className: styles.controls
          }, {
            children: [jsx("div", Object.assign({
              className: prevButtonClass,
              onClick: handlePrevSlide
            }, {
              children: jsx(SvgSliderArrow, {}, void 0)
            }), void 0), jsx("div", Object.assign({
              className: styles.slidesCount
            }, {
              children: jsxs("p", Object.assign({
                className: "ktl-text-2"
              }, {
                children: [index + 1, "/", totalSlides]
              }), void 0)
            }), void 0), jsx("div", Object.assign({
              className: nextButtonClass,
              onClick: handleNextSlide
            }, {
              children: jsx(SvgSliderArrow, {}, void 0)
            }), void 0)]
          }), void 0)]
        }), void 0)]
      }, void 0)]
    }), void 0)
  }), void 0);
};

export { QuotesSlider };
