import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import React__default, { useState } from 'react';
import ReactDOM from 'react-dom';
import classNames from 'classnames';
import styles from './dropdown-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';
import SvgArrowDropdownIcon from './arrow-dropdown-icon.svg.js';
import { useTheme } from '@rescui/ui-contexts';

const DropdownMenu = ({
  homeUrl,
  title,
  mobileTitle = 'Overview',
  items,
  activeIndex,
  linkHandler,
  mobileOverview = true
}) => {
  const theme = useTheme();
  const textCn = useTextStyles();
  const [portalRoot, setPortalRoot] = React__default.useState(null);
  React__default.useEffect(() => {
    if (typeof document !== `undefined`) {
      setPortalRoot(document.body);
    }
  }, []);

  let _items = (mobileOverview ? [{
    title: mobileTitle,
    url: homeUrl
  }] : []).concat(items);

  const _activeIndex = mobileOverview ? activeIndex + 1 : activeIndex;

  const activeItem = _items[_activeIndex];
  const [isExpanded, setIsExpanded] = useState(false);

  const handleClick = () => setIsExpanded(!isExpanded);

  return jsxs(Fragment, {
    children: [jsxs("div", Object.assign({
      className: classNames(styles.dropdownMenu, {
        [styles.dropdownMenuExpanded]: isExpanded
      }),
      onClick: handleClick
    }, {
      children: [jsxs("button", Object.assign({
        className: classNames(styles.button, textCn('rs-text-2')),
        "aria-haspopup": "true"
      }, {
        children: [jsx("span", {
          children: activeItem.title
        }, void 0), jsx(SvgArrowDropdownIcon, {
          className: styles.icon
        }, void 0)]
      }), void 0), jsx("nav", Object.assign({
        className: classNames(styles.dropdownList, {
          [styles.dropdownListDarkTheme]: theme === 'dark'
        })
      }, {
        children: _items.map((item, index) => jsx("a", Object.assign({
          href: item.url,
          className: classNames(styles.dropdownItem, textCn('rs-text-2'), {
            [styles.dropdownItemActive]: index === _activeIndex
          }),
          onClick: event => linkHandler?.(event, item.url),
          target: item.isExternal ? '_blank' : undefined
        }, {
          children: item.title
        }), item.url))
      }), void 0)]
    }), void 0), !!portalRoot && ReactDOM.createPortal(jsx("div", {
      className: classNames(styles.overlay, {
        [styles.overlayVisible]: isExpanded
      }),
      onClick: handleClick
    }, void 0), portalRoot)]
  }, void 0);
};

export { DropdownMenu };
