import { jsx } from 'react/jsx-runtime';
import { useCallback } from 'react';
import classNames from 'classnames';
import styles from './horizontal-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';

const HorizontalMenuItem = ({
  item,
  isActive,
  linkHandler
}) => {
  const textCn = useTextStyles();
  const handleLink = useCallback(event => linkHandler(event, item.url), [item]);
  return isActive ? jsx("span", Object.assign({
    className: styles.itemActive
  }, {
    children: item.title
  }), item.url) : jsx("a", Object.assign({
    href: item.url,
    className: classNames(styles.item, textCn('rs-link', {
      hardness: 'average',
      mode: 'clear'
    })),
    onClick: handleLink,
    target: item.isExternal ? '_blank' : undefined
  }, {
    children: item.title
  }), item.url);
};

const HorizontalMenu = ({
  items,
  activeIndex,
  linkHandler
}) => {
  const textCn = useTextStyles();
  return jsx("nav", Object.assign({
    className: classNames(styles.horizontalMenu, textCn('rs-text-2'))
  }, {
    children: items.map((item, index) => jsx(HorizontalMenuItem, {
      isActive: index === activeIndex,
      item: item,
      linkHandler: linkHandler
    }, item.url))
  }), void 0);
};

export { HorizontalMenu };
