import { jsxs, jsx } from 'react/jsx-runtime';
import { useTheme } from '@rescui/ui-contexts';
import classNames from 'classnames';
import styles from './top-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';
import { HorizontalMenu } from './horizontal-menu/horizontal-menu.js';
import { DropdownMenu } from './dropdown-menu/dropdown-menu.js';

const TopMenu = ({
  homeUrl,
  title,
  mobileTitle,
  activeIndex,
  items,
  linkHandler = () => {},
  className,
  children,
  forwardedRef,
  mobileOverview
}) => {
  const theme = useTheme();
  const textCn = useTextStyles();
  return jsxs("div", Object.assign({
    className: classNames(styles.topMenu, className, {
      [styles.topMenuDarkTheme]: theme === 'dark'
    }),
    ref: forwardedRef
  }, {
    children: [jsx("a", Object.assign({
      href: homeUrl,
      className: classNames(styles.logo, textCn('rs-h3')),
      onClick: event => linkHandler(event, homeUrl)
    }, {
      children: title
    }), void 0), jsx(DropdownMenu, {
      items: items,
      activeIndex: activeIndex,
      linkHandler: linkHandler,
      title: title,
      mobileTitle: mobileTitle,
      homeUrl: homeUrl,
      mobileOverview: mobileOverview
    }, void 0), jsx(HorizontalMenu, {
      items: items,
      activeIndex: activeIndex,
      linkHandler: linkHandler
    }, void 0), children]
  }), void 0);
};

export { TopMenu };
